@@ -34,6 +34,7 @@ from waydroid_helper.compat_widget import (
 from waydroid_helper.compat_widget.message_dialog import MessageDialog
 from waydroid_helper.props_page import PropsPage
 from waydroid_helper.extensions_page import ExtensionsPage
+from waydroid_helper.scripts_page import ScriptsPage
 import os
 from waydroid_helper.config.models import RootConfig
 
@@ -55,6 +56,7 @@ class InstanceDetailPage(NavigationPage):
         # Use lazy loading for page instances
         self._props_page = None
         self._extensions_page = None
+        self._scripts_page = None
         self._pages_created = False
 
         # Create main content first - this is lightweight
@@ -79,6 +81,7 @@ class InstanceDetailPage(NavigationPage):
             self._extensions_page = ExtensionsPage(
                 self.waydroid, navigation_view=self._navigation_view
             )
+            self._scripts_page = ScriptsPage()
             self._pages_created = True
 
             self._replace_placeholder_with_real_pages()
@@ -133,17 +136,37 @@ class InstanceDetailPage(NavigationPage):
         )
         extensions_page.set_icon_name("addon-symbolic")
 
+        # 创建脚本页面占位符
+        scripts_placeholder = Gtk.Box(
+            orientation=Gtk.Orientation.VERTICAL,
+            valign=Gtk.Align.CENTER,
+            halign=Gtk.Align.CENTER,
+        )
+        scripts_placeholder.set_spacing(12)
+        scripts_spinner = Spinner()
+        scripts_label = Gtk.Label(label=_("Loading Scripts..."))
+        scripts_placeholder.append(scripts_spinner)
+        scripts_placeholder.append(scripts_label)
+
+        scripts_page = self.view_stack.add_titled(
+            scripts_placeholder, "scripts", _("Scripts")
+        )
+        scripts_page.set_icon_name("utilities-terminal-symbolic")
+
     def _replace_placeholder_with_real_pages(self):
         """将占位符替换为真实页面"""
-        if self._props_page and self._extensions_page:
+        if self._props_page and self._extensions_page and self._scripts_page:
             # 移除旧的占位符页面
             old_settings = self.view_stack.get_child_by_name("settings")
             old_extensions = self.view_stack.get_child_by_name("extensions")
+            old_scripts = self.view_stack.get_child_by_name("scripts")
 
             if old_settings:
                 self.view_stack.remove(old_settings)
             if old_extensions:
                 self.view_stack.remove(old_extensions)
+            if old_scripts:
+                self.view_stack.remove(old_scripts)
 
             # 添加真实页面
             settings_page = self.view_stack.add_titled(
@@ -156,6 +179,11 @@ class InstanceDetailPage(NavigationPage):
             )
             extensions_page.set_icon_name("addon-symbolic")
 
+            scripts_page = self.view_stack.add_titled(
+                self._scripts_page, "scripts", _("Scripts")
+            )
+            scripts_page.set_icon_name("utilities-terminal-symbolic")
+
     def _create_simple_content(self):
         toolbar_view = ToolbarView.new()
         header_bar = HeaderBar()
@@ -270,7 +298,7 @@ class InstanceDetailPage(NavigationPage):
         current_page = stack.get_visible_child()
 
         current_page_name = stack.get_visible_child_name()
-        if current_page_name in ["settings", "extensions"] and not self._pages_created:
+        if current_page_name in ["settings", "extensions", "scripts"] and not self._pages_created:
             self._ensure_pages_created()
 
         if hasattr(self, "refresh_button"):
@@ -308,9 +336,6 @@ class InstanceDetailPage(NavigationPage):
         key_mapping_group = self._create_key_mapping_group()
         prefs_page.add(key_mapping_group)
 
-        cache_management_group = self._create_cache_management_group()
-        prefs_page.add(cache_management_group)
-
         google_play_group = self._create_google_play_group()
         prefs_page.add(google_play_group)
 
@@ -365,26 +390,6 @@ class InstanceDetailPage(NavigationPage):
 
         return group
 
-    def _create_cache_management_group(self):
-        group = Adw.PreferencesGroup.new()
-        group.set_title(_("Cache Management"))
-
-        clear_cache_row = Adw.ActionRow.new()
-        clear_cache_row.set_title(_("Clear Package Cache"))
-        clear_cache_row.set_subtitle(
-            _("Fix startup issues after installing GApps or microG")
-        )
-
-        self.clear_cache_button = Gtk.Button.new_with_label(_("Clear Cache"))
-        self.clear_cache_button.add_css_class("destructive-action")
-        self.clear_cache_button.set_size_request(160, 40)
-        self.clear_cache_button.connect("clicked", self.on_clear_cache_clicked)
-
-        clear_cache_row.add_suffix(self.clear_cache_button)
-        group.add(clear_cache_row)
-
-        return group
-
     def set_app(self, app: Gtk.Application):
         self._app = app
         self._update_key_mapping_buttons()
@@ -557,8 +562,10 @@ class InstanceDetailPage(NavigationPage):
                 logic_height = self.config.cage.logical_height
                 socket_name = self.config.cage.socket_name
                 scale = self.config.cage.scale/100
+                refresh_rate = self.config.cage.refresh_rate
+                hide_titlebar_flag = "--hide-titlebar" if self.config.cage.hide_titlebar else ""
                 await sm.run(
-                    f"{self.config.cage.executable_path} -W {width} -H {height} -w {logic_width} -h {logic_height} -S {socket_name} --scale {scale} -- waydroid show-full-ui",
+                    f"{self.config.cage.executable_path} -W {width} -H {height} -w {logic_width} -h {logic_height} -S {socket_name} --scale {scale} --refresh-rate {refresh_rate} {hide_titlebar_flag} -- waydroid show-full-ui",
                     flag=True,
                     wait=False,
                 )
@@ -651,116 +658,6 @@ class InstanceDetailPage(NavigationPage):
         self.keymapper_proc = None
         self._update_key_mapping_buttons()
 
-    def on_clear_cache_clicked(self, button: Gtk.Button):
-        """Handle clear cache button click"""
-        logger.info("Clear package cache button clicked")
-        self._show_clear_cache_confirmation(button)
-
-    def _show_clear_cache_confirmation(self, button: Gtk.Button):
-        """Show confirmation dialog before clearing cache"""
-        dialog = MessageDialog(
-            heading=_("Clear Package Cache"),
-            body=_(
-                "This will clear Waydroid package cache files to fix startup issues after installing GApps or microG.\n\nA backup will be created before clearing. Do you want to continue?"
-            ),
-            parent=self.get_root(),
-        )
-
-        dialog.add_response(Gtk.ResponseType.CANCEL, _("Cancel"))
-        dialog.add_response(Gtk.ResponseType.OK, _("Clear Cache"))
-        dialog.set_response_appearance(Gtk.ResponseType.OK, "destructive-action")
-        dialog.set_default_response(Gtk.ResponseType.CANCEL)
-
-        dialog.connect("response", self._on_confirmation_response, button)
-        dialog.present()
-
-    def _on_confirmation_response(self, dialog, response, button: Gtk.Button):
-        """Handle confirmation dialog response"""
-        if (
-            response == Gtk.ResponseType.OK.value_nick
-            or response == Gtk.ResponseType.OK
-        ):
-            logger.debug("User confirmed cache clearing")
-            self._task.create_task(self._clear_package_cache(button))
-        else:
-            logger.info("User cancelled cache clearing")
-
-    async def _clear_package_cache(self, button: Gtk.Button):
-        """Clear Waydroid package cache"""
-        try:
-            button.set_sensitive(False)
-            button.set_label(_("Clearing..."))
-
-            cli_path = os.environ.get("WAYDROID_CLI_PATH")
-            if not cli_path:
-                logger.error("WAYDROID_CLI_PATH environment variable not set")
-                self._show_cache_clear_result(False, _("WAYDROID_CLI_PATH not found"))
-                return
-
-            command = f"{cli_path} clear_package_cache"
-
-            subprocess_manager = SubprocessManager()
-            result = await subprocess_manager.run(command, shell=False)
-
-            logger.debug(f"Clear cache command result: {result}")
-
-            if result["returncode"] == 0:
-                backup_path = self._extract_backup_path(result["stdout"])
-                self._show_cache_clear_result(
-                    True, _("Package cache cleared successfully"), backup_path
-                )
-            else:
-                self._show_cache_clear_result(False, f"Error: {result['stderr']}")
-
-        except Exception as e:
-            logger.error(f"Failed to clear package cache: {e}")
-            self._show_cache_clear_result(False, str(e))
-        finally:
-            button.set_sensitive(True)
-            button.set_label(_("Clear Cache"))
-
-    def _extract_backup_path(self, stdout: str) -> str:
-        """Extract backup file path from command output"""
-        try:
-            lines = stdout.split("\n")
-            for line in lines:
-                if "Creating backup:" in line:
-                    backup_filename = line.split("Creating backup: ")[1].strip()
-                    data_dir = os.path.expanduser("~/.local/share/waydroid/data")
-                    if backup_filename.startswith("../"):
-                        backup_path = os.path.join(data_dir, backup_filename[3:])
-                    else:
-                        backup_path = os.path.join(data_dir, "system", backup_filename)
-                    return backup_path
-        except Exception as e:
-            logger.error(f"Failed to extract backup path: {e}")
-        return ""
-
-    def _show_cache_clear_result(
-        self, success: bool, message: str, backup_path: str = ""
-    ):
-        """Show cache clear operation result"""
-        if success:
-            logger.debug(f"Cache clear success: {message}")
-            heading = _("Cache Cleared Successfully")
-            if backup_path:
-                body = _(
-                    "Package cache has been cleared successfully.\n\nBackup saved to:\n{0}"
-                ).format(backup_path)
-            else:
-                body = _("Package cache has been cleared successfully.")
-        else:
-            logger.error(f"Cache clear failed: {message}")
-            heading = _("Cache Clear Failed")
-            body = _("Failed to clear package cache:\n\n{0}").format(message)
-
-        dialog = MessageDialog(heading=heading, body=body, parent=self.get_root())
-
-        dialog.add_response(Gtk.ResponseType.OK, _("OK"))
-        dialog.set_default_response(Gtk.ResponseType.OK)
-
-        dialog.present()
-
     def _create_google_play_group(self):
         group = Adw.PreferencesGroup.new()
         group.set_title(_("Google Play Services"))
